==> aws-solutions-constructs.aws-wafwebacl-apigateway-2.11.0.tar.gz: aws-solutions-constructs.aws-wafwebacl-apigateway-2.11.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-wafwebacl-apigateway",
    "version": "2.11.0",
    "description": "CDK constructs for defining an AWS web WAF connected to Amazon API Gateway REST API.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_wafwebacl_apigateway",
        "aws_solutions_constructs.aws_wafwebacl_apigateway._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_wafwebacl_apigateway._jsii": [
            "aws-wafwebacl-apigateway@2.11.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_wafwebacl_apigateway": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.24.0, <3.0.0",
        "aws-solutions-constructs.core==2.11.0",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.62.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-wafwebacl-apigateway-2.14.0.tar.gz: aws-solutions-constructs.aws-wafwebacl-apigateway-2.14.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-wafwebacl-apigateway",
    "version": "2.14.0",
    "description": "CDK constructs for defining an AWS web WAF connected to Amazon API Gateway REST API.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_wafwebacl_apigateway",
        "aws_solutions_constructs.aws_wafwebacl_apigateway._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_wafwebacl_apigateway._jsii": [
            "aws-wafwebacl-apigateway@2.14.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_wafwebacl_apigateway": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.36.0, <3.0.0",
        "aws-solutions-constructs.core==2.14.0",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.63.2, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
